==> extjs-lib-comp-0.0.1.tgz: package/tests/src/window/LockingWindowTest.js <==
/**
 * coon.js
 * extjs-lib-comp
 * Copyright (C) 2017-2021 Thorsten Suckow-Homberg https://github.com/coon-js/extjs-lib-comp
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without restriction,
 * including without limitation the rights to use, copy, modify, merge,
 * publish, distribute, sublicense, and/or sell copies of the Software,
 * and to permit persons to whom the Software is furnished to do so,
 * subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
 * OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
 * USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

describe("coon.comp.window.LockingWindowTest", function (t) {

    t.it("Sanitize tests for LockingWindow specifics", function (t) {

        var w = Ext.create("coon.comp.window.LockingWindow", {
            modal: false,
            maximized: false,
            closable: true,
            resizable: true
        });

        // truthies
        t.expect(w.isVisible()).toBeTruthy();

        if (Ext.isModern) {
            t.expect(w.getModal()).toBeTruthy();
            t.expect(w.getMaximized()).toBeTruthy();
        } else {
            t.expect(w.modal).toBeTruthy();
            t.expect(w.maximized).toBeTruthy();
        }

        // falsies
        if (Ext.isModern) {
            t.expect(w.getClosable()).toBeFalsy();
            t.expect(w.getResizable()).toBeFalsy();
        } else {
            t.expect(w.closable).toBeFalsy();
            t.expect(w.resizable).toBeFalsy();
        }


    });


});

==> extjs-lib-comp-1.0.0.tgz: package/tests/src/window/LockingWindowTest.js <==
/**
 * coon.js
 * extjs-lib-comp
 * Copyright (C) 2017-2021 Thorsten Suckow-Homberg https://github.com/coon-js/extjs-lib-comp
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without restriction,
 * including without limitation the rights to use, copy, modify, merge,
 * publish, distribute, sublicense, and/or sell copies of the Software,
 * and to permit persons to whom the Software is furnished to do so,
 * subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
 * OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
 * USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

StartTest((t) => {

    t.it("Sanitize tests for LockingWindow specifics", (t) => {

        var w = Ext.create("coon.comp.window.LockingWindow", {
            modal: false,
            maximized: false,
            closable: true,
            resizable: true
        });

        // truthies
        t.expect(w.isVisible()).toBeTruthy();

        if (Ext.isModern) {
            t.expect(w.getModal()).toBeTruthy();
            t.expect(w.getMaximized()).toBeTruthy();
        } else {
            t.expect(w.modal).toBeTruthy();
            t.expect(w.maximized).toBeTruthy();
        }

        // falsies
        if (Ext.isModern) {
            t.expect(w.getClosable()).toBeFalsy();
            t.expect(w.getResizable()).toBeFalsy();
        } else {
            t.expect(w.closable).toBeFalsy();
            t.expect(w.resizable).toBeFalsy();
        }


    });


});
